Documentation
¶
Index ¶
- Constants
- func CloseActiveSessions()
- func CreateAccount(c echo.Context) error
- func CreateCashFlow(c echo.Context) error
- func CreateDefaultSession() *model.Session
- func CreateImportedCashFlows(c echo.Context) error
- func CreatePayee(c echo.Context) error
- func CreateScheduledCashFlow(c echo.Context) error
- func CreateSecurity(c echo.Context) error
- func CreateSession(c echo.Context) error
- func CreateSplitCashFlow(c echo.Context) error
- func CreateTaxEntry(c echo.Context) error
- func CreateTaxes(c echo.Context) error
- func CreateTrade(c echo.Context) error
- func CreateUser(c echo.Context) error
- func DeleteAccount(c echo.Context) error
- func DeleteCashFlow(c echo.Context) error
- func DeletePayee(c echo.Context) error
- func DeleteSecurity(c echo.Context) error
- func DeleteTaxEntry(c echo.Context) error
- func DeleteTaxes(c echo.Context) error
- func DeleteTrade(c echo.Context) error
- func DeleteUser(c echo.Context) error
- func EditAccount(c echo.Context) error
- func EditCashFlow(c echo.Context) error
- func EditPayee(c echo.Context) error
- func EditSecurity(c echo.Context) error
- func EditTaxEntry(c echo.Context) error
- func EditTrade(c echo.Context) error
- func GetAccount(c echo.Context) error
- func GetCompanyFinancials(c echo.Context) error
- func GetPayee(c echo.Context) error
- func GetSecurity(c echo.Context) error
- func GetTradeGain(c echo.Context) error
- func IsEnabledMultiUser() bool
- func ListAccounts(c echo.Context) error
- func ListImported(c echo.Context) error
- func ListImportedCashFlows(c echo.Context) error
- func ListPayees(c echo.Context) error
- func ListScheduledCashFlows(c echo.Context) error
- func ListSecurities(c echo.Context) error
- func ListTaxCashFlows(c echo.Context) error
- func ListTaxes(c echo.Context) error
- func ListTradeGains(c echo.Context) error
- func Login(c echo.Context) error
- func Logout(c echo.Context) error
- func MergePayee(c echo.Context) error
- func MoveSecurity(c echo.Context) error
- func NewAccount(c echo.Context) error
- func NewSecurity(c echo.Context) error
- func NewUser(c echo.Context) error
- func PayeeSetCategory(c echo.Context) error
- func PutCashFlow(c echo.Context) error
- func RecalculateTaxes(c echo.Context) error
- func StartSessionManager() *scs.SessionManager
- func UpdateAccount(c echo.Context) error
- func UpdateCashFlow(c echo.Context) error
- func UpdatePayee(c echo.Context) error
- func UpdateSecurity(c echo.Context) error
- func UpdateTaxEntry(c echo.Context) error
- func UpdateTrade(c echo.Context) error
- type PutKeyValue
Constants ¶
const SessionExpiry = 3
Variables ¶
This section is empty.
Functions ¶
func CreateAccount ¶
func CreateCashFlow ¶
func CreateDefaultSession ¶
func CreateImportedCashFlows ¶
func CreatePayee ¶
func CreateScheduledCashFlow ¶
func CreateSecurity ¶
func CreateSession ¶
func CreateSplitCashFlow ¶
func CreateTaxEntry ¶
func CreateTaxes ¶
func CreateTrade ¶
func CreateUser ¶
func DeleteAccount ¶
func DeleteCashFlow ¶
func DeletePayee ¶
func DeleteSecurity ¶
func DeleteTaxEntry ¶
func DeleteTaxes ¶
func DeleteTrade ¶
func DeleteUser ¶
func EditAccount ¶
func EditCashFlow ¶
func EditSecurity ¶
func EditTaxEntry ¶
func GetAccount ¶
func GetCompanyFinancials ¶
func GetSecurity ¶
func GetTradeGain ¶
func IsEnabledMultiUser ¶
func IsEnabledMultiUser() bool
could have separate config variable for multi-user, but as this is what sessions are used to managed, just tie to if sessions are enabled.
func ListAccounts ¶
func ListImported ¶
func ListImportedCashFlows ¶
func ListPayees ¶
func ListScheduledCashFlows ¶
func ListSecurities ¶
func ListTaxCashFlows ¶
func ListTradeGains ¶
func MergePayee ¶
func MoveSecurity ¶
func NewAccount ¶
func NewSecurity ¶
func PayeeSetCategory ¶
func PutCashFlow ¶
func RecalculateTaxes ¶
func StartSessionManager ¶
func StartSessionManager() *scs.SessionManager
func UpdateAccount ¶
func UpdateCashFlow ¶
func UpdatePayee ¶
func UpdateSecurity ¶
func UpdateTaxEntry ¶
func UpdateTrade ¶
Types ¶
type PutKeyValue ¶
Click to show internal directories.
Click to hide internal directories.